@@ -158,6 +158,9 @@ static void callerid_widget_dispose (GObject *gobject)
 /*{*/
 /*	CallerIDWidget *self = CALLERID_WIDGET (gobject);*/
 
+/*	g_free (self->priv->new_tp_state);*/
+/*	g_free (self->priv->new_bluez_state);*/
+
 /*	G_OBJECT_CLASS (callerid_widget_parent_class)->finalize (gobject);*/
 /*}*/
 
@@ -324,12 +327,10 @@ static void callerid_widget_on_ready_update (McAccount *account, const GError *e
 	GHashTableIter iter;
 	gpointer key, value;
 
-	if (error)
-		return;
+	g_return_if_fail (error != NULL);
 
 	parameters = mc_account_get_parameters (account);
-	if (!parameters)
-		return;
+	g_return_if_fail (parameters != NULL);
 
 	g_hash_table_iter_init (&iter, parameters);
 	new_params = g_hash_table_new ((GHashFunc) g_str_hash, (GEqualFunc) g_str_equal);
@@ -354,15 +355,13 @@ static void callerid_widget_on_ready_read (McAccount *account, const GError *err
 	const gchar *result;
 	gchar *label;
 
-	if (error)
-		return;
+	g_return_if_fail (error != NULL);
 
 	parameters = mc_account_get_parameters (account);
-	if (!parameters)
-		return;
+	g_return_if_fail (parameters != NULL);
+
 	gvalue = g_hash_table_lookup (parameters, TELEPATHY_PROPERTY);
-	if (!gvalue)
-		return;
+	g_return_if_fail (gvalue != NULL);
 
 	result = g_value_get_string (gvalue);
 
